@@ -462,12 +462,12 @@ int mqtt3_sub_add(struct mosquitto_db *db, struct mosquitto *context, const char
 		child->subs = NULL;
 		child->children = NULL;
 		child->retained = NULL;
-		if(db->subs.children){
-			child->next = db->subs.children;
+		if(root->children){
+			child->next = root->children;
 		}else{
 			child->next = NULL;
 		}
-		db->subs.children = child;
+		root->children = child;
 
 		rc = _sub_add(db, context, qos, child, tokens);
 	}
