@@ -4,10 +4,6 @@
 # Subscription is made with QoS 0 so the retained message should also have QoS
 # 0.
 
-import subprocess
-import socket
-import time
-
 import inspect, os, sys
 # From http://stackoverflow.com/questions/279237/python-import-a-module-from-a-folder
 cmd_subfolder = os.path.realpath(os.path.abspath(os.path.join(os.path.split(inspect.getfile( inspect.currentframe() ))[0],"..")))
