@@ -7,10 +7,8 @@
 
 import inspect
 import os
-import subprocess
 import socket
 import sys
-import time
 
 # From http://stackoverflow.com/questions/279237/python-import-a-module-from-a-folder
 cmd_subfolder = os.path.realpath(os.path.abspath(os.path.join(os.path.split(inspect.getfile( inspect.currentframe() ))[0],"..")))
